<?php
$lan = array(
	"Deleting" => "Eliminando",
	"Done" => "Listo",
	"No template have been defined" => "No se ha definido
	ning&uacute;n patr&oacute;n",
	"Existing templates" => "Patrones existentes",
	"View" => "Ver",
	"Edit" => "Editar",
  'delete' => 'Eliminar',
	"Add new Template" => "A&ntilde;adir patr&oacute;n",
);
?>